Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/pydantic_typer/__init__.py | (no class) | 2 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/main.py | Typer | 6 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/main.py | (no class) | 110 | 0 | 0 | 44 | 1 | 99%
src/pydantic_typer/utils.py | (no class) | 16 | 0 | 21 | 8 | 0 | 100%
unit_tests/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_001_basic.py | (no class) | 18 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_002_nested_models.py | (no class) | 17 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_003_annotated_argument.py | (no class) | 22 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_004_argument_override.py | (no class) | 18 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_005_multi_commands.py | (no class) | 17 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_006_pydantic_types.py | (no class) | 21 | 0 | 0 | 0 | 0 | 100%
Total |  | 247 | 0 | 21 | 52 | 1 | 99%

No items found using the specified filter.